"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.toRendableAccomodation = void 0;

var _utils = require("./utils");

const toRendableAccomodation = (intl, accomodation, stayTaxes) => {
  const {
    merchant,
    merchantName,
    inscriptions
  } = accomodation;
  return {
    code: merchant,
    name: merchantName,
    inscriptions: inscriptions.map(inscription => {
      const {
        description,
        matching: {
          context: {
            paxs,
            dates
          }
        },
        stayTaxCartId
      } = inscription;
      const paxCount = (paxs.adults ? paxs.adults.count : 0) + (paxs.children ? paxs.children.count : 0);
      const stayTax = stayTaxes.find(st => st.id === stayTaxCartId);
      return {
        id: inscription.id,
        label: `${description.room} - ${description.mealPlan}`,
        pax: `${paxCount} ${intl.formatMessage({
          id: "accomodation.people"
        })}`,
        price: (0, _utils.formatPrice)(intl, description.total + (stayTax ? stayTax.price : 0)),
        details: [stayTax ? {
          type: "details",
          label: intl.formatMessage({
            id: "accomodation.stayTax"
          }),
          value: (0, _utils.formatPrice)(intl, stayTax.price)
        } : undefined, {
          type: "details",
          label: intl.formatMessage({
            id: "accomodation.date"
          }),
          value: `${(0, _utils.format)(dates.start, intl.locale)} - ${(0, _utils.format)(new Date(dates.stop), intl.locale)}`
        }].filter(o => o)
      };
    })
  };
};

exports.toRendableAccomodation = toRendableAccomodation;