"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.toRendableEsfCustom = exports.toRendableEsf = void 0;

var _utils = require("./utils");

const toRendableEsf = (intl, esf) => {
  const {
    merchant,
    merchantName,
    inscriptions
  } = esf;
  return {
    code: merchant,
    name: merchantName,
    inscriptions: inscriptions.map(inscription => {
      const {
        id,
        product,
        student,
        students
      } = inscription;
      const {
        name,
        kind,
        level,
        activity,
        price,
        structure,
        options,
        schedule,
        meeting
      } = product;
      const pax = students && students.length > 0 ? students.length > 1 ? `${students.length} ${intl.formatMessage({
        id: "esf.people"
      })}` : students[0].firstname : student.firstname;
      const [lessons, extras] = structure ? structure.reduce((acc, step) => step.schedule ? [[...acc[0], step], acc[1]] : [acc[0], [...acc[1], step]], [[], []]) : [[{
        schedule,
        meeting,
        name
      }], []];
      return {
        id,
        label: name,
        pax,
        subLabel: [{
          type: "normal",
          text: `${kind} ${intl.formatMessage({
            id: "esf.of"
          })}`
        }, {
          type: "bold",
          text: activity
        }, {
          type: "normal",
          text: intl.formatMessage({
            id: "esf.in"
          })
        }, {
          type: "bold",
          text: level
        }],
        price: (0, _utils.formatPrice)(intl, price),
        details: [...lessons.flatMap(lesson => [lessons.length > 1 ? {
          type: "title",
          label: lesson.name
        } : undefined, {
          type: "details",
          label: intl.formatMessage({
            id: "esf.date"
          }),
          value: lesson.schedule.ranges.flatMap(range => [range.date, range.time])
        }, {
          type: "details",
          label: intl.formatMessage({
            id: "esf.place"
          }),
          value: lesson.meeting
        }]), {
          type: "padding"
        }, extras && extras.length > 0 ? {
          type: "details",
          label: intl.formatMessage({
            id: "esf.included"
          }),
          value: extras.map(extra => extra.name)
        } : undefined, options && options.length > 0 ? {
          type: "details",
          label: intl.formatMessage({
            id: "esf.options"
          }),
          value: options.map(option => option.name)
        } : undefined].filter(o => o)
      };
    })
  };
};

exports.toRendableEsf = toRendableEsf;

const toRendableEsfCustom = (intl, esfCustom) => {
  const {
    merchant,
    merchantName,
    inscriptions
  } = esfCustom;
  return {
    code: merchant,
    name: merchantName,
    inscriptions: inscriptions.map(inscription => {
      const {
        id,
        price,
        pax,
        from,
        activity,
        nbPeople,
        meetingPoint
      } = inscription;
      const many = nbPeople > 1;
      return {
        id,
        label: intl.formatMessage({
          id: "esfcustom.title"
        }),
        pax: many ? `${nbPeople} ${intl.formatMessage({
          id: "esfcustom.ppl"
        })}` : `${pax[0].firstname}`,
        subLabel: [{
          type: "normal",
          text: `${intl.formatMessage({
            id: "esfcustom.privateLesson"
          })} ${intl.formatMessage({
            id: "esfcustom.of"
          })}`
        }, {
          type: "bold",
          text: activity.label
        }, {
          type: "normal",
          text: intl.formatMessage({
            id: "esfcustom.in"
          })
        }, {
          type: "bold",
          text: many ? intl.formatMessage({
            id: "esfcustom.group"
          }) : pax[0].levelName
        }],
        price: (0, _utils.formatPrice)(intl, price),
        details: [{
          type: "details",
          label: intl.formatMessage({
            id: "esfcustom.date"
          }),
          value: (0, _utils.format)(from, intl.locale)
        }, {
          type: "details",
          label: intl.formatMessage({
            id: "esfcustom.place"
          }),
          value: meetingPoint.label
        }, many ? {
          type: "details",
          label: intl.formatMessage({
            id: "esfcustom.students"
          }),
          value: pax.map(student => `${student.firstname} ${student.lastname} - ${student.levelName}`)
        } : undefined].filter(o => o)
      };
    })
  };
};

exports.toRendableEsfCustom = toRendableEsfCustom;