"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.toRendableLift = void 0;

var _utils = require("./utils");

const deliveryStr = (intl, delivery) => {
  if (!delivery) return;
  return delivery.mode === "pickup" ? `${intl.formatMessage({
    id: "lift.pickup"
  })} : ${delivery.label}` : `${intl.formatMessage({
    id: "lift.delivery"
  })} ${delivery.price === 0 ? intl.formatMessage({
    id: "lift.free"
  }) : (0, _utils.formatPrice)(intl, delivery.price)}`;
};

const toRendableLift = (intl, lift) => {
  const {
    merchant,
    merchantName,
    inscriptions
  } = lift;
  return {
    code: merchant,
    name: merchantName,
    inscriptions: inscriptions.map(inscription => {
      const {
        id,
        label,
        price,
        delivery,
        from,
        tickets
      } = inscription;
      const many = tickets.length > 1;
      const ticket = tickets[0];
      const deliveryValue = deliveryStr(intl, delivery);
      return {
        id,
        label,
        pax: many ? `${tickets.length} ${intl.formatMessage({
          id: "lift.people"
        })}` : `${ticket.firstname}`,
        subLabel: `${many ? `${tickets.length} ${intl.formatMessage({
          id: "lift.lifts"
        })}` : `${intl.formatMessage({
          id: "lift.lift"
        })} ${ticket.kind}`}${deliveryValue ? ` · ${deliveryValue}` : ""}`,
        price: (0, _utils.formatPrice)(intl, price),
        details: [{
          type: "details",
          label: intl.formatMessage({
            id: "lift.date"
          }),
          value: (0, _utils.format)(from, intl.locale)
        }, ...(many ? tickets.flatMap(ticket => [{
          type: "title",
          label: `${intl.formatMessage({
            id: "lift.lift"
          })} ${ticket.kind}`
        }, {
          type: "details",
          label: intl.formatMessage({
            id: "lift.included"
          }),
          value: ticket.options.join(", ")
        }]) : [{
          type: "details",
          label: intl.formatMessage({
            id: "lift.included"
          }),
          value: ticket.options.join(", ")
        }])]
      };
    })
  };
};

exports.toRendableLift = toRendableLift;