"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.computeMerchant = exports.formatPrice = exports.format = void 0;

var _format = _interopRequireDefault(require("date-fns/format"));

var _fr = _interopRequireDefault(require("date-fns/locale/fr"));

var _en = _interopRequireDefault(require("date-fns/locale/en"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const format = (date, lang = "en", format = "D MMMM YYYY") => {
  return (0, _format.default)(date instanceof Date ? date : new Date(date), format, {
    locale: lang === "fr" ? _fr.default : _en.default
  });
};

exports.format = format;

const formatPrice = (intl, price, options = {}) => intl.formatNumber(price, {
  style: "currency",
  currency: "EUR",
  ...options
});

exports.formatPrice = formatPrice;

const computeSubLabelAndDetails = inscription => {
  const {
    subLabel,
    details
  } = inscription;

  if (subLabel === undefined && details instanceof Array && details.length > 0) {
    return { ...inscription,
      subLabel: details[0],
      details: details.length > 1 ? details.slice(1) : undefined
    };
  } else {
    return inscription;
  }
};

const computeMerchant = ({
  inscriptions,
  ...merchant
}) => {
  return { ...merchant,
    inscriptions: inscriptions.map(computeSubLabelAndDetails)
  };
};

exports.computeMerchant = computeMerchant;