"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _database = require("./database.js");

class SQL {
  constructor(literals, values = []) {
    this.literals = Array.isArray(literals) ? [...literals] : [literals];
    this.values = values;
  }

  get sql() {
    return this.literals.join("?");
  }

  append(partial) {
    const lastIndex = this.literals.length - 1;
    const isPartialSQL = partial instanceof SQL;

    if (isPartialSQL) {
      const [head, ...tail] = partial.literals;
      this.literals[lastIndex] += ` ${head}`;
      this.literals = [...this.literals, ...tail];
      this.values = [...this.values, ...partial.values];
    } else {
      this.literals[lastIndex] += ` ${partial}`;
    }

    return this;
  }

  appendIf(cond, partial) {
    if (cond) {
      this.append(partial);
    }

    return this;
  }

  database(db) {
    this.db = db;
    return this;
  }

  connection(co) {
    if (co) {
      this._connection = co;
    }

    return this;
  }

  execute() {
    return (0, _database.execute)(this.db)(this);
  }

  single(defaultValue) {
    return (0, _database.executeSingle)(this.db, defaultValue)(this);
  }

  insert() {
    return (0, _database.insert)(this.db)(this);
  }

}

Object.defineProperty(SQL.prototype, "sql", {
  enumerable: true
});

var _default = (literals, ...values) => new SQL(literals, values);

exports.default = _default;