"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.UnionBy = exports.Maximum = exports.Minimum = exports.Concat = exports.Sum = exports.Any = exports.All = void 0;

var _union = require("../utils/union");

const sum = {
  append: (acc, x) => acc + x,
  zero: 0
};
const minimum = {
  append: (acc, x) => Math.min(acc, x),
  zero: Number.POSITIVE_INFINITY
};
const maximum = {
  append: (acc, x) => Math.max(acc, x),
  zero: Number.NEGATIVE_INFINITY
};
const all = {
  append: (acc, x) => acc && x,
  zero: true
};
const any = {
  append: (acc, x) => acc || x,
  zero: false
};
const concat = {
  append: (acc, x) => [...acc, ...x],
  zero: []
};

const union = key => {
  const unionByKey = (0, _union.unionBy)(key);
  return {
    append: (acc, x) => unionByKey(acc, x),
    zero: []
  };
};

const All = array => array.reduce(all.append, all.zero);

exports.All = All;

const Any = array => array.reduce(any.append, any.zero);

exports.Any = Any;

const Sum = array => array.reduce(sum.append, sum.zero);

exports.Sum = Sum;

const Concat = array => array.reduce(concat.append, concat.zero);

exports.Concat = Concat;

const Minimum = array => array.reduce(minimum.append, minimum.zero);

exports.Minimum = Minimum;

const Maximum = array => array.reduce(maximum.append, maximum.zero);

exports.Maximum = Maximum;

const UnionBy = key => array => {
  const unionByKey = union(key);
  return array.reduce(unionByKey.append, unionByKey.zero);
};

exports.UnionBy = UnionBy;