"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Failure = exports.Success = void 0;

var _assert = _interopRequireDefault(require("assert"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const isDefined = value => value !== undefined;

const isSuccess = ({
  success
}) => isDefined(success);

const isFailure = ({
  failure
}) => isDefined(failure);

const isValidResult = result => isSuccess(result) || isFailure(result);

const isValidMatcher = matcher => isSuccess(matcher) && isFailure(matcher);

class Result {
  constructor(result) {
    this.result = result;
  }

  match(matcher) {
    (0, _assert.default)(isValidResult(this.result));
    (0, _assert.default)(isValidMatcher(matcher));
    return isSuccess(this.result) ? matcher.success(this.result.success) : matcher.failure(this.result.failure);
  }

  map(f) {
    return isSuccess(this.result) ? Success(f(this.result.success)) : this;
  }

  getOrElse(value) {
    return isSuccess(this.result) ? this.result.success : value;
  }

  get() {
    return this.result.success;
  }

  isSuccess() {
    return isSuccess(this.result);
  }

  isFailure() {
    return isFailure(this.result);
  }

  toString() {
    return this.result.success || this.result.failure;
  }

}

const Success = result => new Result({
  success: result
});

exports.Success = Success;

const Failure = error => new Result({
  failure: error
});

exports.Failure = Failure;