"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.pickOrMax = exports.pickOrZero = exports.pickTime = exports.pickDate = exports.pickBoolean = exports.pickSeq = exports.pickNumber = exports.pickOptional = exports.pick = exports.pickPath = void 0;

var _seq = _interopRequireDefault(require("../types/seq"));

var _curry = _interopRequireDefault(require("./curry.js"));

var _compose = _interopRequireDefault(require("./compose.js"));

var _cast = require("./cast.js");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const isDefined = object => object !== undefined && object !== null;

const isEmpty = array => array.length === 0;

const orZero = x => isDefined(x) ? Number(x) : 0;

const orMax = x => isDefined(x) ? Number(x) : Number.MAX_SAFE_INTEGER;

const pickPath = (0, _curry.default)((path, object) => {
  if (!isDefined(object)) return null;
  if (isEmpty(path)) return object;
  const item = path[0];
  const next = object[item];
  return !isDefined(next) ? null : pickPath(path.slice(1), next);
});
exports.pickPath = pickPath;
const pick = (0, _curry.default)((path, object) => {
  if (!isDefined(object)) return null;
  return object[path];
});
exports.pick = pick;

const pickOptional = path => (0, _compose.default)(_cast.asUndefinedIfNull, pick(path));

exports.pickOptional = pickOptional;

const pickNumber = path => (0, _compose.default)(_cast.asNumber, pick(path));

exports.pickNumber = pickNumber;

const pickSeq = path => (0, _compose.default)(_seq.default, pickPath(path));

exports.pickSeq = pickSeq;

const pickBoolean = path => (0, _compose.default)(_cast.asBoolean, pick(path));

exports.pickBoolean = pickBoolean;

const pickDate = path => (0, _compose.default)(_cast.asDate, pick(path));

exports.pickDate = pickDate;

const pickTime = path => (0, _compose.default)(_cast.asTime, pick(path));

exports.pickTime = pickTime;

const pickOrZero = path => (0, _compose.default)(orZero, pick(path));

exports.pickOrZero = pickOrZero;

const pickOrMax = path => (0, _compose.default)(orMax, pick(path));

exports.pickOrMax = pickOrMax;